"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toReportName = exports.enrichReducedReportWithBaseline = exports.createReducedReport = void 0;
const lh_utils_1 = require("./lh-utils");
const file_1 = require("../../../../core/file");
const utils_1 = require("../persist/utils");
function createReducedReport(flowResult) {
    const steps = (0, lh_utils_1.parseSteps)(flowResult.steps);
    return {
        name: flowResult.name,
        fetchTime: steps[0].fetchTime,
        steps
    };
}
exports.createReducedReport = createReducedReport;
function enrichReducedReportWithBaseline(reducedReport, baselineReport) {
    const baselineReducedReport = createReducedReport(baselineReport);
    const baselineResults = Object.fromEntries(baselineReducedReport.steps.map((step) => [step.name, step.results]));
    const steps = reducedReport.steps.map((step) => (Object.assign(Object.assign({}, step), { 'baseline': baselineResults[step.name] })));
    return Object.assign(Object.assign({}, reducedReport), { steps });
}
exports.enrichReducedReportWithBaseline = enrichReducedReportWithBaseline;
function toReportName(url, flowName, report) {
    const fetchTime = (0, utils_1.isoDateStringToIsoLikeString)(report.steps[0].fetchTime);
    return `${(0, file_1.toFileName)(url)}-${(0, file_1.toFileName)(flowName)}-${(0, utils_1.isoDateStringToIsoLikeString)(fetchTime)}`;
}
exports.toReportName = toReportName;
//# sourceMappingURL=utils.js.map