"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatCode = exports.getParserFromExtname = void 0;
const prettier_1 = require("prettier");
const constants_1 = require("./constants");
function getParserFromExtname(extname) {
    extname = extname[0] === '.' ? extname.slice(1, extname.length) : extname;
    if (!constants_1.supportedExtname.includes(extname)) {
        throw new Error(`Extension name ${extname} is not supported.`);
    }
    return (['md', 'ts', 'js', 'yml'].includes(extname) ? {
        md: 'markdown',
        ts: 'typescript',
        js: 'javascript',
        yml: 'yaml'
    }[extname] : extname);
}
exports.getParserFromExtname = getParserFromExtname;
/**
 * Code formatter that uses prettier under the hood
 *
 * @param code
 * @param parser
 */
function formatCode(code, parser = 'typescript') {
    const prettierConfig = prettier_1.resolveConfig.sync(__dirname);
    return (0, prettier_1.format)(code, Object.assign({ parser }, prettierConfig)).trim();
}
exports.formatCode = formatCode;
//# sourceMappingURL=index.js.map